@@ -4,5 +4,7 @@ zelig2oprobit <- function(formula, model, data, M, ...) {
   mf[[1]] <- MASS::polr
   mf$Hess <- TRUE
   mf$method <- "probit"
+  if (is.character(mf$weights))
+    mf$weights <- as.name(mf$weights)
   as.call(mf)
 }
